bayespy.inference.vmp.nodes.wishart.WishartDistribution.random
==============================================================

.. currentmodule:: bayespy.inference.vmp.nodes.wishart

.. automethod:: WishartDistribution.random